@@ -150,7 +150,7 @@ int vasprintf(char **ptr, const char *format, va_list ap)
 #endif
 #endif
 
-static int root;			/* if we are root, no password is
+static int root = 0;			/* if we are root, no password is
                                            required */
 
 static gint
@@ -285,26 +285,3 @@ su_run_with_password (gchar *exec_path, gchar *password)
 {
 	return exec_su (exec_path, "root", password);
 }
-
-gchar *
-get_size_string (gfloat fsize)
-{
-	
-	if (fsize < 1024.0)
-		return g_strdup_printf (_("%d bytes"), (int)fsize);
-	fsize /= 1024.0;
-	if (fsize < 1024.0) 
-		return g_strdup_printf (_("%d K"), (int)fsize);
-		
-	fsize /= 1024.0;
-	if (fsize < 100.0)
-		return g_strdup_printf (_("%.1f MB"), fsize);
-	else if (fsize < 1024.0)
-		return g_strdup_printf (_("%.0f MB"), fsize);
-	
-	fsize /= 1024.0;
-	return g_strdup_printf (_("%.1f GB"), fsize);
-
-}
-
-
